@@ -1,5 +1,5 @@
 import sys
-from typing import Awaitable, Callable, Optional, TYPE_CHECKING
+from typing import Awaitable, Callable, List, Optional, TYPE_CHECKING
 from rich.segment import Segment
 
 if sys.version_info >= (3, 8):
@@ -20,12 +20,18 @@ class MessageTarget(Protocol):
     async def post_message(self, message: "Message") -> bool:
         ...
 
+    def post_message_no_wait(self, message: "Message") -> bool:
+        ...
+
 
 class EventTarget(Protocol):
     async def post_message(self, message: "Message") -> bool:
         ...
 
+    def post_message_no_wait(self, message: "Message") -> bool:
+        ...
+
 
 MessageHandler = Callable[["Message"], Awaitable]
 
-Lines = list[list[Segment]]
\ No newline at end of file
+Lines = List[List[Segment]]
